@@ -5,8 +5,7 @@
 #
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
-#    the Free Software Foundation; either version 2 of the License, or
-#    (at your option) any later version.
+#    the Free Software Foundation; version 2 of the License.
 #
 #    This program is distributed in the hope that it will be useful,
 #    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -18,4 +17,6 @@
 #    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 __all__ = ['base', 'dir', 'file', 'url', 'gophermap',
-           'UMN', 'html', 'mbox', 'virtual', 'pyg', 'scriptexec']
+           'UMN', 'ZIP', 'html', 'mbox', 'virtual', 'pyg', 'scriptexec']
+#import base, dir, file, gophermap, UMN, html, mbox, virtual, pyg
+#import scriptexec, url
